==> haskell-hls-refactor-plugin-2.0.0.0-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-refactor-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-refactor-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-refactor-plugin-2.0.0.0-8bLMTajILCKB3ndnjtkMg5
key:                  hls-refactor-plugin-2.0.0.0-8bLMTajILCKB3ndnjtkMg5
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           zubin.duggal@gmail.com
author:               The Haskell IDE Team
synopsis:             Exactprint refactorings for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  6fd0722d755cd5170dd6f77daf703d26
exposed:              True
exposed-modules:
    Development.IDE.GHC.Compat.ExactPrint Development.IDE.GHC.Dump
    Development.IDE.GHC.ExactPrint Development.IDE.Plugin.CodeAction
    Development.IDE.Plugin.CodeAction.Util

hidden-modules:
    Development.IDE.Plugin.CodeAction.Args
    Development.IDE.Plugin.CodeAction.ExactPrint
    Development.IDE.Plugin.CodeAction.PositionIndexed
    Development.IDE.Plugin.Plugins.AddArgument
    Development.IDE.Plugin.Plugins.Diagnostic
    Development.IDE.Plugin.Plugins.FillHole
    Development.IDE.Plugin.Plugins.FillTypeWildcard
    Development.IDE.Plugin.Plugins.ImportUtils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-refactor-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-refactor-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-refactor-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-refactor-plugin
hs-libraries:         HShls-refactor-plugin-2.0.0.0-8bLMTajILCKB3ndnjtkMg5
depends:
    aeson-2.1.2.1-8pX4IwvbwpcwXiIiReOQk base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi deepseq-1.4.8.0
    dlist-1.0-I6FB5Nlk17hG16fxQzZSEb
    extra-1.7.16-CT2Pr7M0vEzLXqrliS0eki ghc-9.4.8 ghc-boot-9.4.8
    ghc-exactprint-1.6.1-694PkKnXbLl9d8wFnXFiiq
    ghcide-2.0.0.0-38gaIrWgyfQHpN6wDkMFZK
    hls-graph-2.0.0.0-55C297ZfQE2IuyhX11SfiJ
    hls-plugin-api-2.0.0.0-GCCGW1i6IyxAXqLK4gORTF
    lens-5.2.3-ECHdyiBhGt3AEK5VHs81a3
    lsp-1.6.0.0-3LsX8V7dCXb5SsyCDeu2YI mtl-2.2.2
    regex-tdfa-1.3.2.2-D95SuRi2xoOHQuT5KVAOCg
    retrie-1.2.3-G5nKMLxNFsGJlxCAEQxPIX
    syb-0.7.2.4-GwVxHFFp6zLBbNId74rfEd text-2.0.2
    text-rope-0.3-C7lhJiid9DO9Tzor8vuDXO time-1.12.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-8U9CBLajvKUXcrLJVqNaj

haddock-interfaces:
    /usr/share/doc/haskell-hls-refactor-plugin/html/hls-refactor-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-refactor-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-refactor-plugin-2.0.0.0-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-refactor-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-refactor-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-refactor-plugin-2.0.0.0-8DMPHST2akKJk9fZ5lwtb
key:                  hls-refactor-plugin-2.0.0.0-8DMPHST2akKJk9fZ5lwtb
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           zubin.duggal@gmail.com
author:               The Haskell IDE Team
synopsis:             Exactprint refactorings for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  5a8c100184f9235a4840e85d56c498fe
exposed:              True
exposed-modules:
    Development.IDE.GHC.Compat.ExactPrint Development.IDE.GHC.Dump
    Development.IDE.GHC.ExactPrint Development.IDE.Plugin.CodeAction
    Development.IDE.Plugin.CodeAction.Util

hidden-modules:
    Development.IDE.Plugin.CodeAction.Args
    Development.IDE.Plugin.CodeAction.ExactPrint
    Development.IDE.Plugin.CodeAction.PositionIndexed
    Development.IDE.Plugin.Plugins.AddArgument
    Development.IDE.Plugin.Plugins.Diagnostic
    Development.IDE.Plugin.Plugins.FillHole
    Development.IDE.Plugin.Plugins.FillTypeWildcard
    Development.IDE.Plugin.Plugins.ImportUtils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-refactor-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-refactor-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-refactor-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-refactor-plugin
hs-libraries:         HShls-refactor-plugin-2.0.0.0-8DMPHST2akKJk9fZ5lwtb
depends:
    aeson-2.1.2.1-HgTvGelKFeMCs4MoB4HQQ3 base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi deepseq-1.4.8.0
    dlist-1.0-I6FB5Nlk17hG16fxQzZSEb
    extra-1.7.16-5U9Z4JlXvjsGJBQPJ1GjLc ghc-9.4.8 ghc-boot-9.4.8
    ghc-exactprint-1.6.1-6Dk25UXVu6NJo87bFSXcci
    ghcide-2.0.0.0-6ABiBLao5h014kEH3ydD13
    hls-graph-2.0.0.0-4RbdBH9tIt5AcO4KfLp8ld
    hls-plugin-api-2.0.0.0-1Rv10r62x2d9mEvp4VcVf
    lens-5.2.3-I3BlAHfqsGAEvCz93DUGGV lsp-1.6.0.0-2Oo5MtTAGo3LW7rZdOErf
    mtl-2.2.2 regex-tdfa-1.3.2.2-Lx2wVcETmehVQz7NWfugc
    retrie-1.2.3-5wpfIEJlqndEOBCquL2OTy
    syb-0.7.2.4-5EQR9W4f34Nc1xy39zlm4 text-2.0.2
    text-rope-0.3-WWdhZKOi6tGQCCj7tDcwZ time-1.12.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-6lPJVAOvNaZ2RxvZwsH66g

haddock-interfaces:
    /usr/share/doc/haskell-hls-refactor-plugin/html/hls-refactor-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-refactor-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
